@@ -96,7 +96,12 @@ class Engine:
             pipeline, root_pipeline_data, root_pipeline_context, subprocess_context, **options
         )
         # execute from start event
-        self.runtime.execute(process_id, pipeline["start_event"]["id"])
+        self.runtime.execute(
+            process_id=process_id,
+            node_id=pipeline["start_event"]["id"],
+            root_pipeline_id=pipeline["id"],
+            parent_pipeline_id=pipeline["id"],
+        )
 
         self.runtime.post_prepare_run_pipeline(
             pipeline, root_pipeline_data, root_pipeline_context, subprocess_context, **options
@@ -155,7 +160,12 @@ class Engine:
         if info_list:
             self.runtime.batch_resume(process_id_list=[i.process_id for i in info_list])
             for info in info_list:
-                self.runtime.execute(info.process_id, info.current_node)
+                self.runtime.execute(
+                    process_id=info.process_id,
+                    node_id=info.current_node,
+                    root_pipeline_id=info.root_pipeline_id,
+                    parent_pipeline_id=info.top_pipeline_id,
+                )
 
         self.runtime.post_resume_pipeline(pipeline_id)
 
@@ -198,7 +208,12 @@ class Engine:
         # found process suspended by node suspend
         for info in info_list:
             self.runtime.resume(process_id=info.process_id)
-            self.runtime.execute(info.process_id, info.current_node)
+            self.runtime.execute(
+                process_id=info.process_id,
+                node_id=info.current_node,
+                root_pipeline_id=info.root_pipeline_id,
+                parent_pipeline_id=info.top_pipeline_id,
+            )
 
         self.runtime.post_resume_node(node_id)
 
@@ -218,13 +233,14 @@ class Engine:
 
         state = self.runtime.get_state(node_id)
 
-        process_id = self._ensure_state_is_fail_and_return_process_id(state)
+        process_info = self._ensure_state_is_fail_and_return_process_info(state)
 
         self.runtime.pre_retry_node(node_id, data)
 
         if data is not None:
             self.runtime.set_data_inputs(
-                node_id, {k: DataInput(need_render=True, value=v) for k, v in data.items()},
+                node_id,
+                {k: DataInput(need_render=True, value=v) for k, v in data.items()},
             )
 
         self._add_history(node_id, state)
@@ -238,7 +254,12 @@ class Engine:
             clear_archived_time=True,
         )
 
-        self.runtime.execute(process_id, node_id)
+        self.runtime.execute(
+            process_id=process_info.process_id,
+            node_id=node_id,
+            root_pipeline_id=process_info.root_pipeline_id,
+            parent_pipeline_id=process_info.top_pipeline_id,
+        )
 
         self.runtime.post_retry_node(node_id, data)
 
@@ -257,15 +278,13 @@ class Engine:
 
         state = self.runtime.get_state(node_id)
 
-        process_id = self._ensure_state_is_fail_and_return_process_id(state)
+        process_info = self._ensure_state_is_fail_and_return_process_info(state)
 
         self.runtime.pre_retry_subprocess(node_id)
 
-        proc_info = self.runtime.get_process_info(process_id)
-
         # reset pipeline stack
-        if proc_info.pipeline_stack[-1] == node_id:
-            self.runtime.set_pipeline_stack(process_id, proc_info.pipeline_stack[:-1])
+        if process_info.pipeline_stack[-1] == node_id:
+            self.runtime.set_pipeline_stack(process_info.process_id, process_info.pipeline_stack[:-1])
 
         self._add_history(node_id, state)
 
@@ -278,7 +297,12 @@ class Engine:
             clear_archived_time=True,
         )
 
-        self.runtime.execute(process_id, node_id)
+        self.runtime.execute(
+            process_id=process_info.process_id,
+            node_id=node_id,
+            root_pipeline_id=process_info.root_pipeline_id,
+            parent_pipeline_id=process_info.top_pipeline_id,
+        )
 
         self.runtime.post_retry_subprocess(node_id)
 
@@ -301,7 +325,7 @@ class Engine:
 
         state = self.runtime.get_state(node_id)
 
-        process_id = self._ensure_state_is_fail_and_return_process_id(state)
+        process_info = self._ensure_state_is_fail_and_return_process_info(state)
 
         self.runtime.pre_skip_node(node_id)
 
@@ -311,12 +335,21 @@ class Engine:
         self._add_history(node_id, state)
 
         self.runtime.set_state(
-            node_id=node_id, to_state=states.FINISHED, is_skip=True, refresh_version=True, set_archive_time=True,
+            node_id=node_id,
+            to_state=states.FINISHED,
+            is_skip=True,
+            refresh_version=True,
+            set_archive_time=True,
         )
 
         # 跳过节点时不再做节点输出提取到上下文的操作
         # 因为节点失败的位置未知，可能提取出来的变量是无法预知的，会导致不可预知的行为
-        self.runtime.execute(process_id, next_node_id)
+        self.runtime.execute(
+            process_id=process_info.process_id,
+            node_id=next_node_id,
+            root_pipeline_id=process_info.root_pipeline_id,
+            parent_pipeline_id=process_info.top_pipeline_id,
+        )
 
         self.runtime.post_skip_node(node_id)
 
@@ -339,17 +372,26 @@ class Engine:
 
         state = self.runtime.get_state(node_id)
 
-        process_id = self._ensure_state_is_fail_and_return_process_id(state)
+        process_info = self._ensure_state_is_fail_and_return_process_info(state)
 
         self.runtime.pre_skip_exclusive_gateway(node_id, flow_id)
 
         self._add_history(node_id, state)
 
         self.runtime.set_state(
-            node_id=node_id, to_state=states.FINISHED, is_skip=True, refresh_version=True, set_archive_time=True,
+            node_id=node_id,
+            to_state=states.FINISHED,
+            is_skip=True,
+            refresh_version=True,
+            set_archive_time=True,
         )
 
-        self.runtime.execute(process_id, next_node_id)
+        self.runtime.execute(
+            process_id=process_info.process_id,
+            node_id=next_node_id,
+            root_pipeline_id=process_info.root_pipeline_id,
+            parent_pipeline_id=process_info.top_pipeline_id,
+        )
 
         self.runtime.post_skip_exclusive_gateway(node_id, flow_id)
 
@@ -388,7 +430,10 @@ class Engine:
 
         old_ver = state.version
         new_ver = self.runtime.set_state(
-            node_id=node_id, to_state=states.FAILED, refresh_version=True, set_archive_time=True,
+            node_id=node_id,
+            to_state=states.FAILED,
+            refresh_version=True,
+            set_archive_time=True,
         )
 
         self.runtime.set_execution_data_outputs(node_id, outputs)
@@ -413,9 +458,9 @@ class Engine:
         :raises InvalidOperationError: [description]
         """
 
-        process_id = self.runtime.get_sleep_process_with_current_node_id(node_id)
+        process_info = self.runtime.get_sleep_process_info_with_current_node_id(node_id)
 
-        if not process_id:
+        if not process_info:
             raise InvalidOperationError("can not find process with current node id: {}".format(node_id))
 
         state = self.runtime.get_state(node_id)
@@ -436,14 +481,14 @@ class Engine:
 
         data_id = self.runtime.set_callback_data(node_id, state.version, data)
 
-        self.runtime.schedule(process_id, node_id, schedule.id, data_id)
+        self.runtime.schedule(process_info.process_id, node_id, schedule.id, data_id)
 
         self.runtime.post_callback(node_id, version, data)
 
     # engine event
     @setup_gauge(ENGINE_RUNNING_PROCESSES)
     @setup_histogram(ENGINE_PROCESS_RUNNING_TIME)
-    def execute(self, process_id: int, node_id: str):
+    def execute(self, process_id: int, node_id: str, root_pipeline_id: str, parent_pipeline_id: str):
         """
         在某个进程上从某个节点开始进入推进循环
 
@@ -451,29 +496,67 @@ class Engine:
         :type process_id: int
         :param node_id: 节点 ID
         :type node_id: str
+        :param root_pipeline_id: 根流程 ID
+        :type root_pipeline_id: str
+        :param parent_pipeline_id: 父流程 ID
+        :type parent_pipeline_id: str
         """
-
-        process_info = self.runtime.get_process_info(process_id)
-        self.runtime.wake_up(process_id)
-
         current_node_id = node_id
 
+        # 推进前准备
+        try:
+            process_info = self.runtime.get_process_info(process_id)
+            self.runtime.wake_up(process_id)
+        except Exception:
+            ex_data = traceback.format_exc()
+            logger.exception(
+                "[%s]execute node(%s) prepare fail",
+                root_pipeline_id,
+                current_node_id,
+            )
+
+            self.runtime.sleep(process_id)
+
+            outputs = self.runtime.get_execution_data_outputs(current_node_id)
+            outputs["ex_data"] = ex_data
+            self.runtime.set_execution_data_outputs(current_node_id, outputs)
+
+            self.runtime.set_state(
+                node_id=current_node_id,
+                to_state=states.FAILED,
+                root_id=root_pipeline_id,
+                parent_id=parent_pipeline_id,
+                set_started_time=True,
+                set_archive_time=True,
+            )
+
+            return
+
         # 推进循环
         while True:
             # 进程心跳
-            self.runtime.beat(process_id)
-
-            # 遇到推进终点后需要尝试唤醒父进程
-            if current_node_id == process_info.destination_id:
-                self.runtime.die(process_id)
-                wake_up_seccess = self.runtime.child_process_finish(process_info.parent_id, process_id)
-
-                if wake_up_seccess:
-                    self.runtime.execute(process_info.parent_id, process_info.destination_id)
-
-                return
+            try:
+                self.runtime.beat(process_id)
+            except Exception:
+                # do not fail the flow when beat failed
+                logger.exception("process(%s) beat error" % process_id)
 
             try:
+                # 遇到推进终点后需要尝试唤醒父进程
+                if current_node_id == process_info.destination_id:
+                    self.runtime.die(process_id)
+                    wake_up_seccess = self.runtime.child_process_finish(process_info.parent_id, process_id)
+
+                    if wake_up_seccess:
+
+                        self.runtime.execute(
+                            process_id=process_info.parent_id,
+                            node_id=process_info.destination_id,
+                            root_pipeline_id=process_info.root_pipeline_id,
+                            parent_pipeline_id=process_info.top_pipeline_id,
+                        )
+
+                    return
 
                 self.runtime.set_current_node(process_id, current_node_id)
 
@@ -488,7 +571,9 @@ class Engine:
                 if node_state_map[process_info.root_pipeline_id] == states.REVOKED:
                     self.runtime.die(process_id)
                     logger.info(
-                        "[%s] root pipeline revoked checked at node %s", process_info.root_pipeline_id, current_node_id,
+                        "[%s] root pipeline revoked checked at node %s",
+                        process_info.root_pipeline_id,
+                        current_node_id,
                     )
                     return
 
@@ -523,7 +608,9 @@ class Engine:
 
                         self.runtime.set_execution_data_outputs(current_node_id, exec_outputs)
                         self.runtime.set_state(
-                            node_id=current_node_id, to_state=states.FAILED, set_archive_time=True,
+                            node_id=current_node_id,
+                            to_state=states.FAILED,
+                            set_archive_time=True,
                         )
                         self.runtime.sleep(process_id)
 
@@ -617,7 +704,12 @@ class Engine:
                     )
                     self.runtime.join(process_id, children)
                     for d in execute_result.dispatch_processes:
-                        self.runtime.execute(d.process_id, d.node_id)
+                        self.runtime.execute(
+                            process_id=d.process_id,
+                            node_id=d.node_id,
+                            root_pipeline_id=process_info.root_pipeline_id,
+                            parent_pipeline_id=process_info.top_pipeline_id,
+                        )
 
                 if execute_result.should_die:
                     self.runtime.die(process_id)
@@ -666,7 +758,11 @@ class Engine:
     @setup_gauge(ENGINE_RUNNING_SCHEDULES)
     @setup_histogram(ENGINE_SCHEDULE_RUNNING_TIME)
     def schedule(
-        self, process_id: int, node_id: str, schedule_id: str, callback_data_id: Optional[int] = None,
+        self,
+        process_id: int,
+        node_id: str,
+        schedule_id: str,
+        callback_data_id: Optional[int] = None,
     ):
         """
         在某个进程上开始某个节点的调度
@@ -776,7 +872,10 @@ class Engine:
                 type_label = self._get_metrics_node_type(node)
 
                 logger.info(
-                    "[%s] before schedule node %s with data %s", root_pipeline_id, node, callback_data,
+                    "[%s] before schedule node %s with data %s",
+                    root_pipeline_id,
+                    node,
+                    callback_data,
                 )
                 schedule_start = time.time()
                 schedule_result = handler.schedule(process_info, state.loop, state.inner_loop, schedule, callback_data)
@@ -784,16 +883,27 @@ class Engine:
 
                 if schedule_result.has_next_schedule:
                     self.runtime.set_next_schedule(
-                        process_info.process_id, node_id, schedule_id, schedule_result.schedule_after,
+                        process_info.process_id,
+                        node_id,
+                        schedule_id,
+                        schedule_result.schedule_after,
                     )
 
                 if schedule_result.schedule_done:
                     self.runtime.finish_schedule(schedule_id)
-                    self.runtime.execute(process_id, schedule_result.next_node_id)
+                    self.runtime.execute(
+                        process_id=process_id,
+                        node_id=schedule_result.next_node_id,
+                        root_pipeline_id=process_info.root_pipeline_id,
+                        parent_pipeline_id=process_info.top_pipeline_id,
+                    )
         except Exception as e:
             ex_data = traceback.format_exc()
             logger.warning(
-                "[%s]schedule exception catch at node(%s): %s", root_pipeline_id, node_id, ex_data,
+                "[%s]schedule exception catch at node(%s): %s",
+                root_pipeline_id,
+                node_id,
+                ex_data,
             )
 
             # state version already changed, so give up this schedule
@@ -823,7 +933,10 @@ class Engine:
         self.runtime.release_schedule_lock(schedule_id)
 
     def _add_history(
-        self, node_id: str, state: Optional[State] = None, exec_data: Optional[ExecutionData] = None,
+        self,
+        node_id: str,
+        state: Optional[State] = None,
+        exec_data: Optional[ExecutionData] = None,
     ) -> int:
         if not state:
             state = self.runtime.get_state(node_id)
@@ -843,16 +956,16 @@ class Engine:
             outputs=exec_data.outputs,
         )
 
-    def _ensure_state_is_fail_and_return_process_id(self, state: State) -> str:
+    def _ensure_state_is_fail_and_return_process_info(self, state: State) -> str:
         if state.name != states.FAILED:
             raise InvalidOperationError("{} state is not FAILED, actual {}".format(state.node_id, state.name))
 
-        process_id = self.runtime.get_sleep_process_with_current_node_id(state.node_id)
+        process_info = self.runtime.get_sleep_process_info_with_current_node_id(state.node_id)
 
-        if not process_id:
+        if not process_info:
             raise InvalidOperationError("can not find sleep process with current node id: {}".format(state.node_id))
 
-        return process_id
+        return process_info
 
     def _get_metrics_node_type(self, node: Node) -> str:
         if node.type != NodeType.ServiceActivity:
